@@ -154,6 +154,7 @@ class EventSub:
         self._host: str = '0.0.0.0'
         self.__running = False
         self.__callbacks = {}
+        self._closing = False
         self.__active_webhooks = {}
         self.__hook_thread: Union['threading.Thread', None] = None
         self.__hook_loop: Union['asyncio.AbstractEventLoop', None] = None
@@ -176,10 +177,7 @@ class EventSub:
         site = web.TCPSite(runner, str(self._host), self._port, ssl_context=self.__ssl_context)
         self.__hook_loop.run_until_complete(site.start())
         self.logger.info('started twitch API event sub on port ' + str(self._port))
-        try:
-            self.__hook_loop.run_forever()
-        except (CancelledError, asyncio.CancelledError):
-            self.logger.debug('we got cancelled')
+        self.__hook_loop.run_until_complete(self._keep_loop_alive())
 
     def start(self):
         """Starts the EventSub client
@@ -191,8 +189,13 @@ class EventSub:
             raise RuntimeError('already started')
         self.__hook_thread = threading.Thread(target=self.__run_hook, args=(self.__build_runner(),))
         self.__running = True
+        self._closing = False
         self.__hook_thread.start()
 
+    async def _keep_loop_alive(self):
+        while not self._closing:
+            await asyncio.sleep(0.1)
+
     async def stop(self):
         """Stops the EventSub client
 
@@ -200,16 +203,19 @@ class EventSub:
 
         :rtype: None
         """
+        self.logger.debug('shutting down eventsub')
         if self.__hook_runner is not None and self.unsubscribe_on_stop:
             await self.unsubscribe_all_known()
-        tasks = {t for t in asyncio.all_tasks(loop=self.__hook_loop) if not t.done()}
-        for task in tasks:
-            task.cancel()
         # ensure all client sessions are closed
         await asyncio.sleep(0.25)
-        self.__hook_loop.call_soon_threadsafe(self.__hook_loop.stop)
+        self._closing = True
+        # cleanly shut down the runner
+        await self.__hook_runner.shutdown()
+        await self.__hook_runner.cleanup()
+        # self.__hook_loop.call_soon_threadsafe(self.__hook_loop.stop)
         self.__hook_runner = None
         self.__running = False
+        self.logger.debug('eventsub shut down')
 
     # ==================================================================================================================
     # HELPER
@@ -1080,3 +1086,88 @@ class EventSub:
             'moderator_user_id': moderator_user_id
         }
         return await self._subscribe('channel.shield_mode.end', '1', param, callback)
+
+    async def listen_channel_charity_campaign_start(self,
+                                                    broadcaster_user_id: str,
+                                                    callback: CALLBACK_TYPE) -> str:
+        """Sends a notification when the broadcaster starts a charity campaign.
+
+        Requires the :const:`~twitchAPI.types.AuthScope.CHANNEL_READ_CHARITY` auth scope.
+
+        For more information see here: https://dev.twitch.tv/docs/eventsub/eventsub-subscription-types/#channelcharity_campaignstart
+
+        :param broadcaster_user_id: The ID of the broadcaster that you want to receive notifications about when they start a charity campaign.
+        :param callback: function for callback
+        :raises ~twitchAPI.types.EventSubSubscriptionConflict: if a conflict was found with this subscription
+            (e.g. already subscribed to this exact topic)
+        :raises ~twitchAPI.types.EventSubSubscriptionTimeout: if :code:`wait_for_subscription_confirm`
+            is true and the subscription was not fully confirmed in time
+        :raises ~twitchAPI.types.EventSubSubscriptionError: if the subscription failed (see error message for details)
+        :raises ~twitchAPI.types.TwitchBackendException: if the subscription failed due to a twitch backend error
+        """
+        param = {'broadcaster_user_id': broadcaster_user_id}
+        return await self._subscribe('channel.charity_campaign.start', '1', param, callback)
+
+    async def listen_channel_charity_campaign_progress(self,
+                                                       broadcaster_user_id: str,
+                                                       callback: CALLBACK_TYPE) -> str:
+        """Sends notifications when progress is made towards the campaign’s goal or when the broadcaster changes the fundraising goal.
+
+        Requires the :const:`~twitchAPI.types.AuthScope.CHANNEL_READ_CHARITY` auth scope.
+
+        For more information see here: https://dev.twitch.tv/docs/eventsub/eventsub-subscription-types/#channelcharity_campaignprogress
+
+        :param broadcaster_user_id: The ID of the broadcaster that you want to receive notifications about when their campaign makes progress or
+                is updated.
+        :param callback: function for callback
+        :raises ~twitchAPI.types.EventSubSubscriptionConflict: if a conflict was found with this subscription
+            (e.g. already subscribed to this exact topic)
+        :raises ~twitchAPI.types.EventSubSubscriptionTimeout: if :code:`wait_for_subscription_confirm`
+            is true and the subscription was not fully confirmed in time
+        :raises ~twitchAPI.types.EventSubSubscriptionError: if the subscription failed (see error message for details)
+        :raises ~twitchAPI.types.TwitchBackendException: if the subscription failed due to a twitch backend error
+        """
+        param = {'broadcaster_user_id': broadcaster_user_id}
+        return await self._subscribe('channel.charity_campaign.progress', '1', param, callback)
+
+    async def listen_channel_charity_campaign_stop(self,
+                                                   broadcaster_user_id: str,
+                                                   callback: CALLBACK_TYPE) -> str:
+        """Sends a notification when the broadcaster stops a charity campaign.
+
+        Requires the :const:`~twitchAPI.types.AuthScope.CHANNEL_READ_CHARITY` auth scope.
+
+        For more information see here: https://dev.twitch.tv/docs/eventsub/eventsub-subscription-types/#channelcharity_campaignstop
+
+        :param broadcaster_user_id: The ID of the broadcaster that you want to receive notifications about when they stop a charity campaign.
+        :param callback: function for callback
+        :raises ~twitchAPI.types.EventSubSubscriptionConflict: if a conflict was found with this subscription
+            (e.g. already subscribed to this exact topic)
+        :raises ~twitchAPI.types.EventSubSubscriptionTimeout: if :code:`wait_for_subscription_confirm`
+            is true and the subscription was not fully confirmed in time
+        :raises ~twitchAPI.types.EventSubSubscriptionError: if the subscription failed (see error message for details)
+        :raises ~twitchAPI.types.TwitchBackendException: if the subscription failed due to a twitch backend error
+        """
+        param = {'broadcaster_user_id': broadcaster_user_id}
+        return await self._subscribe('channel.charity_campaign.stop', '1', param, callback)
+
+    async def listen_channel_charity_campaign_donate(self,
+                                                     broadcaster_user_id: str,
+                                                     callback: CALLBACK_TYPE) -> str:
+        """Sends a notification when a user donates to the broadcaster’s charity campaign.
+
+        Requires the :const:`~twitchAPI.types.AuthScope.CHANNEL_READ_CHARITY` auth scope.
+
+        For more information see here: https://dev.twitch.tv/docs/eventsub/eventsub-subscription-types/#channelcharity_campaigndonate
+
+        :param broadcaster_user_id: The ID of the broadcaster that you want to receive notifications about when users donate to their campaign.
+        :param callback: function for callback
+        :raises ~twitchAPI.types.EventSubSubscriptionConflict: if a conflict was found with this subscription
+            (e.g. already subscribed to this exact topic)
+        :raises ~twitchAPI.types.EventSubSubscriptionTimeout: if :code:`wait_for_subscription_confirm`
+            is true and the subscription was not fully confirmed in time
+        :raises ~twitchAPI.types.EventSubSubscriptionError: if the subscription failed (see error message for details)
+        :raises ~twitchAPI.types.TwitchBackendException: if the subscription failed due to a twitch backend error
+        """
+        param = {'broadcaster_user_id': broadcaster_user_id}
+        return await self._subscribe('channel.charity_campaign.donate', '1', param, callback)
